Struct google_cloudshell1::api::AuthorizeEnvironmentRequest [−][src]
pub struct AuthorizeEnvironmentRequest {
pub access_token: Option<String>,
pub expire_time: Option<String>,
pub id_token: Option<String>,
}Expand description
Request message for AuthorizeEnvironment.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- environments authorize users (request)
Fields
access_token: Option<String>The OAuth access token that should be sent to the environment.
expire_time: Option<String>The time when the credentials expire. If not set, defaults to one hour from when the server received the request.
id_token: Option<String>The OAuth ID token that should be sent to the environment.