Struct google_cloudshell1::api::RemovePublicKeyRequest [−][src]
Request message for RemovePublicKey.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- environments remove public key users (request)
Fields
key: Option<String>Key that should be removed from the environment.