Struct google_cloudshell1::api::StartEnvironmentRequest [−][src]
pub struct StartEnvironmentRequest {
pub access_token: Option<String>,
pub public_keys: Option<Vec<String>>,
}Expand description
Request message for StartEnvironment.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- environments start users (request)
Fields
access_token: Option<String>The initial access token passed to the environment. If this is present and valid, the environment will be pre-authenticated with gcloud so that the user can run gcloud commands in Cloud Shell without having to log in. This code can be updated later by calling AuthorizeEnvironment.
public_keys: Option<Vec<String>>Public keys that should be added to the environment before it is started.