Struct google_cloudshell1::CancelOperationRequest [−][src]
pub struct CancelOperationRequest { /* fields omitted */ }The request message for Operations.CancelOperation.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- cancel operations (request)